@@ -34,6 +34,14 @@ class AnyProperty(Property):
     template: ClassVar[Optional[str]] = "any_property.py.jinja"
 
 
+@attr.s(auto_attribs=True, frozen=True)
+class NoneProperty(Property):
+    """A property that can only be None"""
+
+    _type_string: ClassVar[str] = "None"
+    _json_type_string: ClassVar[str] = "None"
+
+
 @attr.s(auto_attribs=True, frozen=True)
 class StringProperty(Property):
     """A property of type str"""
@@ -263,6 +271,8 @@ def _string_based_property(
             default=convert("datetime.datetime", data.default),
             nullable=data.nullable,
             python_name=python_name,
+            description=data.description,
+            example=data.example,
         )
     if string_format == "date":
         return DateProperty(
@@ -271,6 +281,8 @@ def _string_based_property(
             default=convert("datetime.date", data.default),
             nullable=data.nullable,
             python_name=python_name,
+            description=data.description,
+            example=data.example,
         )
     if string_format == "binary":
         return FileProperty(
@@ -279,6 +291,8 @@ def _string_based_property(
             default=None,
             nullable=data.nullable,
             python_name=python_name,
+            description=data.description,
+            example=data.example,
         )
     return StringProperty(
         name=name,
@@ -287,6 +301,8 @@ def _string_based_property(
         pattern=data.pattern,
         nullable=data.nullable,
         python_name=python_name,
+        description=data.description,
+        example=data.example,
     )
 
 
@@ -296,10 +312,10 @@ def build_enum_property(
     name: str,
     required: bool,
     schemas: Schemas,
-    enum: Union[List[str], List[int]],
+    enum: Union[List[Optional[str]], List[Optional[int]]],
     parent_name: Optional[str],
     config: Config,
-) -> Tuple[Union[EnumProperty, PropertyError], Schemas]:
+) -> Tuple[Union[EnumProperty, NoneProperty, PropertyError], Schemas]:
     """
     Create an EnumProperty from schema data.
 
@@ -316,11 +332,36 @@ def build_enum_property(
         A tuple containing either the created property or a PropertyError describing what went wrong AND update schemas.
     """
 
+    if len(enum) == 0:
+        return PropertyError(detail="No values provided for Enum", data=data), schemas
+
     class_name = data.title or name
     if parent_name:
         class_name = f"{utils.pascal_case(parent_name)}{utils.pascal_case(class_name)}"
     class_info = Class.from_string(string=class_name, config=config)
-    values = EnumProperty.values_from_list(enum)
+
+    # OpenAPI allows for null as an enum value, but it doesn't make sense with how enums are constructed in Python.
+    # So instead, if null is a possible value, make the property nullable.
+    # Mypy is not smart enough to know that the type is right though
+    value_list: Union[List[str], List[int]] = [value for value in enum if value is not None]  # type: ignore
+    if len(value_list) < len(enum):
+        data.nullable = True
+
+    # It's legal to have an enum that only contains null as a value, we don't bother constructing an enum in that case
+    if len(value_list) == 0:
+        return (
+            NoneProperty(
+                name=name,
+                required=required,
+                nullable=False,
+                default="None",
+                python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+                description=None,
+                example=None,
+            ),
+            schemas,
+        )
+    values = EnumProperty.values_from_list(value_list)
 
     if class_info.name in schemas.classes_by_name:
         existing = schemas.classes_by_name[class_info.name]
@@ -332,11 +373,7 @@ def build_enum_property(
                 schemas,
             )
 
-    for value in values.values():
-        value_type = type(value)
-        break
-    else:
-        return PropertyError(data=data, detail="No values provided for Enum"), schemas
+    value_type = type(next(iter(values.values())))
 
     prop = EnumProperty(
         name=name,
@@ -347,6 +384,8 @@ def build_enum_property(
         value_type=value_type,
         default=None,
         python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+        description=data.description,
+        example=data.example,
     )
 
     default = get_enum_default(prop, data)
@@ -424,6 +463,8 @@ def build_union_property(
             inner_properties=sub_properties,
             nullable=data.nullable,
             python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+            description=data.description,
+            example=data.example,
         ),
         schemas,
     )
@@ -453,7 +494,8 @@ def build_list_property(
         name=f"{name}_item", required=True, data=data.items, schemas=schemas, parent_name=parent_name, config=config
     )
     if isinstance(inner_prop, PropertyError):
-        return PropertyError(data=inner_prop.data, detail=f"invalid data in items of array {name}"), schemas
+        inner_prop.header = f'invalid data in items of array named "{name}"'
+        return inner_prop, schemas
     return (
         ListProperty(
             name=name,
@@ -462,6 +504,8 @@ def build_list_property(
             inner_property=inner_prop,
             nullable=data.nullable,
             python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+            description=data.description,
+            example=data.example,
         ),
         schemas,
     )
@@ -545,6 +589,8 @@ def _property_from_data(
                 required=required,
                 nullable=data.nullable,
                 python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+                description=data.description,
+                example=data.example,
             ),
             schemas,
         )
@@ -556,6 +602,8 @@ def _property_from_data(
                 required=required,
                 nullable=data.nullable,
                 python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+                description=data.description,
+                example=data.example,
             ),
             schemas,
         )
@@ -567,6 +615,8 @@ def _property_from_data(
                 default=convert("bool", data.default),
                 nullable=data.nullable,
                 python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+                description=data.description,
+                example=data.example,
             ),
             schemas,
         )
@@ -585,6 +635,8 @@ def _property_from_data(
             nullable=False,
             default=None,
             python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
+            description=data.description,
+            example=data.example,
         ),
         schemas,
     )
